//
//  ViewController.swift
//  CarManager
//
//  Created by Holger Hinzberg on 25.04.15.
//  Copyright (c) 2015 Holger Hinzberg. All rights reserved.
//

import UIKit

class ViewController: UIViewController
{
    @IBOutlet var fuelLabel: UILabel!
    @IBOutlet var milageLabel: UILabel!
    @IBOutlet var averageConsumptionLabel: UILabel!

    var consumptionCalc:ConsumptionCalculator?
    var numberFormatter:NSNumberFormatter?
    
    override func viewDidLoad()
    {
        super.viewDidLoad()
        self.consumptionCalc = ConsumptionCalculator()
        self.fuelLabel.text = "0,00 Liter"
        self.milageLabel.text = "0 km"
        self.averageConsumptionLabel.text = ""
        10
        self.numberFormatter = NSNumberFormatter()
        self.numberFormatter?.numberStyle = NSNumberFormatterStyle.DecimalStyle
        // Die aktuellen Landeseinstellungen zuweisen
        self.numberFormatter?.locale = NSLocale.currentLocale()
        // Zwei Nachkommastellen sollen es sein
        self.numberFormatter?.minimumFractionDigits = 2
        self.numberFormatter?.maximumFractionDigits = 2
    }

    override func didReceiveMemoryWarning() {
        super.didReceiveMemoryWarning()
        // Dispose of any resources that can be recreated.
    }
    
    @IBAction func fuelSliderDidMove(sender: AnyObject)
    {
        // Den sender wieder in einen UISlider umwandeln
        let slider = sender as? UISlider
        if let slider = slider
        {
            // Den Schiebereglerwert dem Calculator zuweisen
            self.consumptionCalc!.fuel = Double(slider.value)
            // Den Wert zur Kontroller auf der Konsole ausgeben
            print("Kraftstoff: \(self.consumptionCalc!.fuel)")
            
            let fuelString = self.formatDoubleToString(self.consumptionCalc!.fuel)
            
            let value = String(format: "%@ Liter", fuelString)
            self.fuelLabel.text = value
            
            // Rechnen und anzeigen
            self.calculateAndShowAverageConsumption()
        }
    }
    
    @IBAction func milageSliderDidMove(sender: AnyObject)
    {
        // Den sender wieder in einen UISlider umwandeln
        let slider = sender as? UISlider
        if let slider = slider
        {
            // Den Schiebereglerwert dem Calculator zuweisen
            // Durch die Umwandlung in einer ganze Zahl werden
            // die Nachkommastellen abgeschnitten
            let intValue = Int(slider.value)
            self.consumptionCalc!.milage = Double(intValue)
            
            // Den Wert zur Kontroller auf der Konsole ausgeben
            print("Kilometerstand: \(self.consumptionCalc!.milage)")
            
            let value = String(format: "%.0f km", self.consumptionCalc!.milage)
            self.milageLabel.text = value
            
            // Rechnen und anzeigen
            self.calculateAndShowAverageConsumption()
        }
    }
    
    func calculateAndShowAverageConsumption()
    {
        // Das Ergebnis errechnen
        var result:Double = self.consumptionCalc!.calculateConsumption()
        
        if result.isNaN == true || result.isInfinite == true
        {
            result = 0.0
        }
        
        // Den Zahlenwert in einen formatierten Text umwandeln
        let stringResult = self.formatDoubleToString(result)
        
        // In eine Zeichenkette mit zwei
        // Nachkommastellen umwandeln
        // var resultText
        // = String(format: "%.2f Liter pro 100 km", result)
        
        // Einen Bereich bilden, der der vollstängigen String abdeckt
        // var resultRange =
        //   Range<String.Index>(start: resultText.startIndex, end: resultText.endIndex)
        
        // Alle Punkte durch Kommas ersetzen
        // resultText = resultText.stringByReplacingOccurrencesOfString(
        //    ".", withString: ",", options: NSStringCompareOptions.LiteralSearch, range: resultRange)
        
        self.averageConsumptionLabel.text = stringResult + " Liter pro 100 km"
    }
    
    func formatDoubleToString(inValue:Double) -> String
    {
        var value = inValue
        
        if value.isNaN == true || value.isInfinite == true
        {
            value = 0.0
        }
        
        let stringValue = self.numberFormatter?.stringFromNumber(value)
        if let stringValue = stringValue
        {
            // Umwandlung erfolgreich
            return stringValue
        }
        
        // Umwandlung nicht erfolgreich
        return ""
    }
}

































